
<p align="center">
    <a href="https://ibb.co/pvx3rgVs"><img src="/misc/xcavation-logo.png" width="180%"></a> <br>
</p>

<p align="center">

[![SPHEREx QR2](https://img.shields.io/badge/SPHEREx-QR2-green)](https://irsa.ipac.caltech.edu/data/SPHEREx/docs/overview_qr.html)
[![PyPI version](https://img.shields.io/pypi/v/xcavation)](https://pypi.org/project/xcavation/)
[![PyPI downloads](https://img.shields.io/pypi/dm/xcavation)](https://pypistats.org/packages/xcavation)
[![DOI](https://zenodo.org/badge/18316250.svg)](https://doi.org/10.5281/zenodo.18316250)

</p>


<div align="center">
  <p id="description" > <b>Xcavation</b> is a Python package for rapid forced-photometry calculations of <a href="https://spherex.caltech.edu/">SPHEREx</a> QR2 spectral data. It uses the <code>astroquery.irsa</code> package to access <a href="https://spherex.caltech.edu/">SPHEREx</a> images through the IRSA API. Both aperture and PSF photometry are supported and include multi-threading for improved performance.  </p>
</div>

<div align="center">
  <h2 style="font-size: 2em;"> 🔍 Example 🔎 </h2>
</div>

<div align="center">
  <p style="font-size: 1.2em;"> <b>
      The example notebook is provided through <a href="https://drive.google.com/file/d/1S0iLap2IoNdk4ErpdEyMyipBvJeaJ3ay/view?usp=sharing">Google Colab</a>, as it has excellent internet speed for the image API.
    </b> </p>
</div>

<div align="center">
  <h2 style="font-size: 2em;">🛠️ Installation 🛠️</h2>
</div>

<div align="center">
<pp><b> pip Installation </b><pp>
</div>
<div align="center">
</div>

1. **Download Python:** Visit [here](https://www.python.org/downloads/) to install Python 
2. **Download pip:** Visit [here](https://pip.pypa.io/en/stable/installation/) to install pip
3. **Run Install Command:** Run the command in terminal:
   ```bash
   pip install xcavation

<div align="center">
  <h2 style="font-size: 2em;">📞 Support Team 📞</h2>
</div>

- **Mr. Hunter Brooks**
  - hbrooks8 (at) rockets.utoledo.edu
- **Dr. Michael Cushing**

<div align="center">
  <h2 style="font-size: 2em;">📖 Acknowledgments 📖</h2>
</div>

1. If you intend to publish any calculations done by xcavation, please reference Brooks et al. (in prep.).

2. Please reference the relevant [SPHEREx citations](https://spherex.caltech.edu/page/publications).

